# coding: utf-8

"""
    LINE Messaging API(Insight)

    This document describes LINE Messaging API(Insight).  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic.v1 import BaseModel, Field, conlist
from linebot.v3.insight.models.get_statistics_per_unit_response_click import GetStatisticsPerUnitResponseClick
from linebot.v3.insight.models.get_statistics_per_unit_response_message import GetStatisticsPerUnitResponseMessage
from linebot.v3.insight.models.get_statistics_per_unit_response_overview import GetStatisticsPerUnitResponseOverview

class GetStatisticsPerUnitResponse(BaseModel):
    """
    Response object for `get statistics per unit`
    https://developers.line.biz/en/reference/messaging-api/#get-statistics-per-unit-response
    """
    overview: GetStatisticsPerUnitResponseOverview = Field(...)
    messages: conlist(GetStatisticsPerUnitResponseMessage) = Field(..., description="Array of information about individual message bubbles.")
    clicks: conlist(GetStatisticsPerUnitResponseClick) = Field(..., description="Array of information about opened URLs in the message.")

    __properties = ["overview", "messages", "clicks"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetStatisticsPerUnitResponse:
        """Create an instance of GetStatisticsPerUnitResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic.v1 by calling `to_dict()` of overview
        if self.overview:
            _dict['overview'] = self.overview.to_dict()
        # override the default output from pydantic.v1 by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item in self.messages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['messages'] = _items
        # override the default output from pydantic.v1 by calling `to_dict()` of each item in clicks (list)
        _items = []
        if self.clicks:
            for _item in self.clicks:
                if _item:
                    _items.append(_item.to_dict())
            _dict['clicks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetStatisticsPerUnitResponse:
        """Create an instance of GetStatisticsPerUnitResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetStatisticsPerUnitResponse.parse_obj(obj)

        _obj = GetStatisticsPerUnitResponse.parse_obj({
            "overview": GetStatisticsPerUnitResponseOverview.from_dict(obj.get("overview")) if obj.get("overview") is not None else None,
            "messages": [GetStatisticsPerUnitResponseMessage.from_dict(_item) for _item in obj.get("messages")] if obj.get("messages") is not None else None,
            "clicks": [GetStatisticsPerUnitResponseClick.from_dict(_item) for _item in obj.get("clicks")] if obj.get("clicks") is not None else None
        })
        return _obj




# coding: utf-8

"""
    LINE Messaging API(Insight)

    This document describes LINE Messaging API(Insight).  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic.v1 import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator

class SubscriptionPeriodTile(BaseModel):
    """
    SubscriptionPeriodTile
    """
    subscription_period: Optional[StrictStr] = Field(None, alias="subscriptionPeriod", description="Subscription period. Possible values: `within7days`, `within90days`, `unknown` etc.")
    percentage: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="Percentage. Possible values: [0.0,100.0] e.g. 0, 2.9, 37.6.")

    __properties = ["subscriptionPeriod", "percentage"]

    @validator('subscription_period')
    def subscription_period_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('within7days', 'within30days', 'within90days', 'within180days', 'within365days', 'over365days', 'unknown'):
            raise ValueError("must be one of enum values ('within7days', 'within30days', 'within90days', 'within180days', 'within365days', 'over365days', 'unknown')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SubscriptionPeriodTile:
        """Create an instance of SubscriptionPeriodTile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SubscriptionPeriodTile:
        """Create an instance of SubscriptionPeriodTile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SubscriptionPeriodTile.parse_obj(obj)

        _obj = SubscriptionPeriodTile.parse_obj({
            "subscription_period": obj.get("subscriptionPeriod"),
            "percentage": obj.get("percentage")
        })
        return _obj




# coding: utf-8

"""
    Webhook Type Definition

    Webhook event definition of the LINE Messaging API  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr

class Emoji(BaseModel):
    """
    Emoji
    """
    index: StrictInt = Field(..., description="Index position for a character in text, with the first character being at position 0.")
    length: StrictInt = Field(..., description="The length of the LINE emoji string. For LINE emoji (hello), 7 is the length.")
    product_id: StrictStr = Field(..., alias="productId", description="Product ID for a LINE emoji set.")
    emoji_id: StrictStr = Field(..., alias="emojiId", description="ID for a LINE emoji inside a set.")

    __properties = ["index", "length", "productId", "emojiId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Emoji:
        """Create an instance of Emoji from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Emoji:
        """Create an instance of Emoji from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Emoji.parse_obj(obj)

        _obj = Emoji.parse_obj({
            "index": obj.get("index"),
            "length": obj.get("length"),
            "product_id": obj.get("productId"),
            "emoji_id": obj.get("emojiId")
        })
        return _obj

